aboutsummaryrefslogtreecommitdiff
path: root/util-linux/mkfs_minix.c
diff options
context:
space:
mode:
authorBernhard Reutner-Fischer <rep.dot.nop@gmail.com>2008-07-21 13:33:22 +0000
committerBernhard Reutner-Fischer <rep.dot.nop@gmail.com>2008-07-21 13:33:22 +0000
commite1e5174942d4624e3abb8b98fe404afdbb4edad1 (patch)
tree90df2597a9ee281f4fe0aee8cfacf037e6123397 /util-linux/mkfs_minix.c
parent525936195718b40ddb29f30fa87c15c1533c1d08 (diff)
downloadbusybox-e1e5174942d4624e3abb8b98fe404afdbb4edad1.tar.gz
- s/super.block/superblock/g; # for consistency; -1b
Diffstat (limited to 'util-linux/mkfs_minix.c')
-rw-r--r--util-linux/mkfs_minix.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/util-linux/mkfs_minix.c b/util-linux/mkfs_minix.c
index ceeb72a2b..8c3991a99 100644
--- a/util-linux/mkfs_minix.c
+++ b/util-linux/mkfs_minix.c
@@ -109,7 +109,7 @@ struct globals {
unsigned currently_testing;
char root_block[BLOCK_SIZE];
- char super_block_buffer[BLOCK_SIZE];
+ char superblock_buffer[BLOCK_SIZE];
char boot_block_buffer[512];
unsigned short good_blocks_table[MAX_GOOD_BLOCKS];
/* check_blocks(): buffer[] was the biggest static in entire bbox */
@@ -133,7 +133,7 @@ static ALWAYS_INLINE unsigned div_roundup(unsigned size, unsigned n)
#define INODE_BUF1 (((struct minix1_inode*)G.inode_buffer) - 1)
#define INODE_BUF2 (((struct minix2_inode*)G.inode_buffer) - 1)
-#define SB (*(struct minix_super_block*)G.super_block_buffer)
+#define SB (*(struct minix_superblock*)G.superblock_buffer)
#define SB_INODES (SB.s_ninodes)
#define SB_IMAPS (SB.s_imap_blocks)
@@ -235,7 +235,7 @@ static int get_size(const char *file)
static void write_tables(void)
{
/* Mark the super block valid. */
SB.s_state |= MINIX_VALID_FS;
SB.s_state &= ~MINIX_ERROR_FS;
@@ -249,7 +249,7 @@ static void write_tables(void)
xlseek(dev_fd, BLOCK_SIZE, SEEK_SET);
msg_eol = "cannot write superblock";
- xwrite(dev_fd, G.super_block_buffer, BLOCK_SIZE);
+ xwrite(dev_fd, G.superblock_buffer, BLOCK_SIZE);
msg_eol = "cannot write inode map";
xwrite(dev_fd, G.inode_map, SB_IMAPS * BLOCK_SIZE);
@@ -556,7 +556,7 @@ static void setup_tables(void)
unsigned sb_zmaps;
unsigned i;
- /* memset(G.super_block_buffer, 0, BLOCK_SIZE); */
+ /* memset(G.superblock_buffer, 0, BLOCK_SIZE); */
/* memset(G.boot_block_buffer, 0, 512); */
SB_MAGIC = G.magic;
SB_ZONE_SIZE = 0;
@@ -235,7 +235,7 @@ static int get_size(const char *file)
static void write_tables(void)
{
- /* Mark the super block valid. */
+ /* Mark the superblock valid. */
SB.s_state |= MINIX_VALID_FS;
SB.s_state &= ~MINIX_ERROR_FS;